@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: DialogFactory.cpp,v 1.8 2004/11/17 05:42:22 vkurland Exp $
+  $Id: DialogFactory.cpp,v 1.8.4.3 2005/10/27 04:48:12 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -134,8 +134,13 @@ QWidget *DialogFactory::createDialog(QWidget *parent,const QString &objType)
 
 
 QWidget *DialogFactory::createFWDialog(QWidget *parent,FWObject *o)
+    throw(FWException)
 {
-    string dlgname=Resources::platform_res[o->getStr("platform")]->Resources::getResourceStr("/FWBuilderResources/Target/dialog");
+    Resources* platform = Resources::platform_res[o->getStr("platform")];
+    if (platform==NULL)
+        throw FWException((const char*)(QObject::tr("Support module for %1 is not available").arg(o->getStr("platform").c_str()).local8Bit()));
+
+    string dlgname=platform->Resources::getResourceStr("/FWBuilderResources/Target/dialog");
 
 //    string pl=o->getStr("platform");
     if (dlgname=="iptables") return new iptAdvancedDialog(parent,o);
@@ -151,8 +156,13 @@ QWidget *DialogFactory::createFWDialog(QWidget *parent,FWObject *o)
 
 
 QWidget *DialogFactory::createOSDialog(QWidget *parent,FWObject *o)
+    throw(FWException)
 {
-    string dlgname=Resources::os_res[o->getStr("host_OS")]->Resources::getResourceStr("/FWBuilderResources/Target/dialog");
+    Resources *os = Resources::os_res[o->getStr("host_OS")];
+    if (os==NULL)
+        throw FWException((const char*)(QObject::tr("Support module for %1 is not available").arg(o->getStr("host_OS").c_str()).local8Bit()));
+
+    string dlgname=os->Resources::getResourceStr("/FWBuilderResources/Target/dialog");
 
 //    string os=o->getStr("host_OS");
     if (dlgname=="pix_os")    return new pixosAdvancedDialog(parent,o);
