@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: LibraryDialog.h,v 1.8 2004/06/06 20:45:49 vkurland Exp $
+  $Id: LibraryDialog.h,v 1.9 2004/10/20 05:58:46 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -45,7 +45,7 @@ class LibraryDialog : public LibraryDialog_q
     void changeIds(libfwbuilder::FWObject *root);
     
  public:
-    LibraryDialog(QWidget *parent) : LibraryDialog_q(parent) { obj=NULL; }
+    LibraryDialog(QWidget *parent);
     
 public slots:
     virtual void changed();
