@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ObjectEditor.cpp,v 1.24 2004/06/20 06:01:21 vkurland Exp $
+  $Id: ObjectEditor.cpp,v 1.27 2004/12/17 07:23:19 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -211,35 +211,30 @@ void ObjectEditor::hide()
 
 bool ObjectEditor::isVisible()
 {
-    return (visible!=-1);
+    return (visible!=-1 && dialogs[visible]->isVisible());
 }
 
 void ObjectEditor::open(FWObject *obj)
 {
     if (stackIds.count(obj->getTypeName().c_str())!=0)
     {
+        disconnectSignals();
+
         int wid= stackIds[obj->getTypeName().c_str()];
 
-        disconnect( SIGNAL(loadObject_sign(libfwbuilder::FWObject*)) );
-        disconnect( SIGNAL(validate_sign(bool*)) );
-        disconnect( SIGNAL(isChanged_sign(bool*)) );
-        disconnect( SIGNAL(applyChanges_sign()) );
-
-//        parent->setUpdatesEnabled(false);
-//        setUpdatesEnabled(false);
+//        disconnect( SIGNAL(loadObject_sign(libfwbuilder::FWObject*)) );
+//        disconnect( SIGNAL(validate_sign(bool*)) );
+//        disconnect( SIGNAL(isChanged_sign(bool*)) );
+//        disconnect( SIGNAL(applyChanges_sign()) );
+//        disconnect( SIGNAL(discardChanges_sign()) );
+//        disconnect( SIGNAL(close_sign(QCloseEvent*)) );
 
         hide();
 
         visible=wid;
 
-//        parent->adjustSize();
-//        adjustSize();
-
         show();
 
-//        setUpdatesEnabled(true);
-//        parent->setUpdatesEnabled(true);
-
         connect(this, SIGNAL(loadObject_sign(libfwbuilder::FWObject*)),
                 dialogs[ wid ],
                 SLOT(loadFWObject(libfwbuilder::FWObject*)));
@@ -270,66 +265,166 @@ void ObjectEditor::open(FWObject *obj)
     opened = obj;
 }
 
+void ObjectEditor::disconnectSignals()
+{
+    disconnect( SIGNAL(loadObject_sign(libfwbuilder::FWObject*)) );
+    disconnect( SIGNAL(validate_sign(bool*)) );
+    disconnect( SIGNAL(isChanged_sign(bool*)) );
+    disconnect( SIGNAL(applyChanges_sign()) );
+    disconnect( SIGNAL(discardChanges_sign()) );
+    if (visible>=0) dialogs[visible]->disconnect( this );
+}
+
 /* editor window needs to close. Check if something changed in it and
- * accept or not closing event
+ * accept or ignore closing event
  */
 void ObjectEditor::validateAndClose(QCloseEvent *e)
 {
-    if (validateDialog()) e->accept();
-    else                  e->ignore();
-}
+    if (fwbdebug) qDebug("ObjectEditor::validateAndClose");
 
-bool ObjectEditor::validateDialog()
-{
-    if (opened==NULL) return true;
-    bool isgood=true;
-
-    try
+    bool ischanged=false;
+    emit isChanged_sign(&ischanged);
+/* if nothing changed or tree is read-only, just close dialog */
+    if (!ischanged || !isTreeReadWrite(dialogs[ visible ],FWObjectDatabase::db))
     {
-        emit validate_sign( &isgood );
-    
-        if (isgood)
-        {
-            bool ischanged=false;
-            emit isChanged_sign(&ischanged);
-            if (!ischanged) return true;
-            if (!isTreeReadWrite(dialogs[ visible ],FWObjectDatabase::db) )
-                return true;
+        if (fwbdebug)
+            qDebug("ObjectEditor::validateAndClose  accepting close event, no changes");
+        e->accept();
+        disconnectSignals();
+        return;
+    }
 
 /* there are changes and the tree is writable */
-            if (st->getAutoSave())
+    bool saveData = false;
+    if (st->getAutoSave())
+    {
+        saveData = true;
+    } else
+    {
+        switch( QMessageBox::warning(dialogs[ visible ],
+                                     "Firewall Builder",
+                                     tr("This object has been modified but not saved.\nDo you want to save it ?"),
+                                     tr("&Save"), tr("&Discard"), tr("&Continue editing"),
+                                     0, 2 ) )
+        {
+        case 0:   // Save
+            saveData = true;
+            break;
+
+        case 1:   // Discard
+            if (fwbdebug)
+                qDebug("ObjectEditor::validateAndClose  accepting close event, discard changes");
+            emit discardChanges_sign();
+            e->accept();
+            disconnectSignals();
+            return;
+
+        case 2:   // Continue editing
+            e->ignore();
+            return;
+        }
+    }
+
+    if (saveData)
+    {
+        bool isgood=true;
+        emit validate_sign( &isgood );
+        if (isgood)
+        {
+            emit applyChanges_sign();
+            e->accept();
+            disconnectSignals();
+            return;
+        } else
+        {
+            switch ( QMessageBox::warning(dialogs[ visible ],
+                                          "Firewall Builder",
+                                          tr("Modifications done to this object can not be saved.\nDo you want to continue editing it ?"),
+                                          tr("&Edit"),
+                                          tr("&Discard"),
+                                          QString::null,
+                                          0, 1 ) )
             {
-                emit applyChanges_sign();
-                return true;
-            } else
-            {
-                switch ( QMessageBox::warning(dialogs[ visible ],
-                                              "Firewall Builder",
-                                              tr("This object has been modified but not saved.\nDo you want to save it before switching to another object?"),
-                                              tr("&Save"), tr("&Discard"), tr("&Continue editing"),
-                                              0, 2 ) )
-                {
-                case 0:
-                    emit applyChanges_sign();
-                    return true;
-                    break;
-                case 1:
-                    emit discardChanges_sign();
-                    return true;
-                    break;
-                case 2:
-                    return false;
-                    break;
-                }
+            case 0:   // Edit
+                if (fwbdebug)
+                    qDebug("ObjectEditor::validateAndClose  ignoring close event, continue editing");
+                e->ignore();
+                break;
+
+            default:  // Discard
+                if (fwbdebug)
+                    qDebug("ObjectEditor::validateAndClose  accepting close event, discard changes");
+                emit discardChanges_sign();
+                e->accept();
+                disconnectSignals();
             }
         }
     }
-    catch (FWException &ex)
+}
+
+bool ObjectEditor::validateAndSave()
+{
+    if (fwbdebug) qDebug("ObjectEditor::validateAndSave");
+    
+    bool ischanged=false;
+    emit isChanged_sign(&ischanged);
+/* if nothing changed or tree is read-only, just close dialog */
+    if (!ischanged || !isTreeReadWrite(dialogs[ visible ],FWObjectDatabase::db))
     {
-/* catch all unhandled exceptions that could happen during validation
- * or saving */
-        cerr << "Unknown exception in ObjectManipulator::validateDialog(): " << ex.toString() << endl;
+        if (fwbdebug)
+            qDebug("ObjectEditor::validateAndSave: no changes");
+        return true;
     }
-    return false;
+
+/* there are changes and the tree is writable */
+    bool isgood=true;
+    emit validate_sign( &isgood );
+    if (!isgood)
+    {
+        switch ( QMessageBox::warning(dialogs[ visible ],
+                                      "Firewall Builder",
+                                      tr("Modifications done to this object can not be saved.\nDo you want to continue editing it ?"),
+                                      tr("&Edit"),
+                                      tr("&Discard"),
+                                      QString::null,
+                                      0, 1 ) )
+        {
+        case 0:
+            if (fwbdebug)
+                qDebug("ObjectEditor::validateAndSave:  return false, can not switch to another object");
+            return false;
+
+        default:
+            if (fwbdebug)
+                qDebug("ObjectEditor::validateAndSave  return true, discard changes, can switch to another object");
+            return true;
+        }
+        return false;
+    }
+/* changes have been validated, need to save now */
+    if (st->getAutoSave())
+    {
+        emit applyChanges_sign();
+    } else
+    {
+        switch ( QMessageBox::warning(dialogs[ visible ],
+                                      "Firewall Builder",
+                                      tr("This object has been modified but not saved.\nDo you want to save it ?"),
+                                      tr("&Save"), tr("&Discard"), tr("&Continue editing"),
+                                      0, 2 ) )
+        {
+        case 0:
+            emit applyChanges_sign();
+            return true;
+
+        case 1:
+            emit discardChanges_sign();
+            return true;
+
+        case 2:
+            return false;
+        }
+    }
+    return true;
 }
 
