@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: SSHSession.cpp,v 1.14.4.5 2005/09/08 06:05:57 vkurland Exp $
+  $Id: SSHSession.cpp,v 1.14.4.6 2006/03/26 17:36:27 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -38,6 +38,7 @@
 #include <qmessagebox.h>
 #include <qapplication.h>
 #include <qeventloop.h>
+#include <qcstring.h>
 
 #include <iostream>
 
@@ -247,13 +248,16 @@ void SSHSession::sendLine()
     while (input.size()!=0 && n<10)
     {
         QString s = input.front();
+        s = s + "\n";
         if (fwbdebug)
             qDebug("SSHSession::sendLine : %d lines to go -- %s",input.size(),s.ascii());
-
         input.pop_front();
+        QCString csc = s.utf8();
+        if (fwbdebug)
+            qDebug("SSHSession::sendLine : cs='%s'",(const char*)(csc));
 
         stdoutBuffer="";
-        proc->writeToStdin( s+"\n"); // send even if s is empty
+        proc->writeToStdin(csc); // send even if s is empty
         n++;
     }
     emit updateProgressBar_sign(input.size(),false);
