@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: instDialog.cpp,v 1.65.4.4 2005/09/13 04:55:41 vkurland Exp $
+  $Id: instDialog.cpp,v 1.65.4.5 2006/03/26 17:36:27 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -587,13 +587,21 @@ void instDialog::initiateCopy(const QString &file)
         appendRich(QObject::tr("Can not open file %1").arg(ff));
         return;
     }
+
+    /* need to convert strings of the config file from Utf-8 to
+     * internal presentation of QT (unicode) so we can process them
+     * using methods of QString; will convert them back to Utf-8
+     * before sending to the installer process
+     */
     string s0;
     while ( !config_file->eof() )
     {
         getline( *config_file, s0);
-        
-        QString s(s0.c_str());
+        QString s = QString::fromUtf8(s0.c_str());
         s.stripWhiteSpace();
+
+        if (fwbdebug) qDebug("instDialog::initiateCopy s='%s'",s.ascii());
+
         allConfig.push_back(s);
     }
     config_file->close();
