@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: ipfAdvancedDialog.cpp,v 1.10 2005/04/10 07:16:39 vkurland Exp $
+  $Id: ipfAdvancedDialog.cpp,v 1.10.4.1 2005/09/04 20:49:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -52,6 +52,7 @@ ipfAdvancedDialog::ipfAdvancedDialog(QWidget *parent,FWObject *o)
     : ipfAdvancedDialog_q(parent)
 {
     obj=o;
+    QStringList slm;
 
     FWOptions *fwopt=(Firewall::cast(obj))->getOptionsObject();
     assert(fwopt!=NULL);
@@ -96,25 +97,25 @@ ipfAdvancedDialog::ipfAdvancedDialog(QWidget *parent,FWObject *o)
     data.registerOption( ipf_optimize             ,fwopt, "optimize"  );
     data.registerOption( ipf_dynAddr              ,fwopt, "dynAddr"   );
 
-    QStringList logLevels= getLogLevels( obj->getStr("platform").c_str() );
-
+    slm = getLogLevels( obj->getStr("platform").c_str() );
     logLevel->clear();
-    logLevel->insertStringList(logLevels);
-
-    QStringList logFacilities= getLogFacilities( obj->getStr("platform").c_str() );
+    logLevel->insertStringList( getScreenNames( slm ));
+    data.registerOption( logLevel             , fwopt,  "ipf_log_level" ,   slm);
 
+    slm = getLogFacilities( obj->getStr("platform").c_str() );
     logFacility->clear();
-    logFacility->insertStringList(logFacilities);    
-
-    data.registerOption( logLevel             , fwopt,  "ipf_log_level" );
-    data.registerOption( logFacility          , fwopt,  "ipf_log_facility");
+    logFacility->insertStringList( getScreenNames( slm ));    
+    data.registerOption( logFacility          , fwopt,  "ipf_log_facility", slm);
 
     data.registerOption( compiler             , fwopt,  "compiler" );
     data.registerOption( compilerArgs         , fwopt,  "cmdline"  );
     data.registerOption( outputFileName       , fwopt,  "output_file"  );
 
-    data.registerOption( actionOnReject       , fwopt,  "action_on_reject" );
+    slm=getActionsOnReject( obj->getStr("platform").c_str() );
+    actionOnReject->clear();
+    actionOnReject->insertStringList(getScreenNames(slm));
 
+    data.registerOption( actionOnReject       , fwopt,  "action_on_reject",slm);
     data.registerOption( mgmt_ssh             , fwopt,  "mgmt_ssh"  );
     data.registerOption( mgmt_addr            , fwopt,  "mgmt_addr" );
 
