@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: main.cpp,v 1.89.4.3 2005/10/25 06:11:26 vkurland Exp $
+  $Id: main.cpp,v 1.89.4.4 2006/03/26 17:36:27 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -456,6 +456,9 @@ int main( int argc, char ** argv )
 
         #define BUFFSIZE 512
 
+#ifdef DEBUG_INSTALLER
+        int debug_file = open("installer.dbg",O_CREAT|O_WRONLY);
+#endif
         char    ibuf[BUFFSIZE];
         char    obuf[BUFFSIZE];
         bool    endOfStream = false;
@@ -498,8 +501,31 @@ int main( int argc, char ** argv )
                         endOfStream = true;
                     } else
                     {
-                        int r=writen(mfd,ibuf,n);
+/* This is a workaround for the problem that exists with utf-8 encoded data
+ * passed to stdin of a QProcess (and vice versa, see
+ * http://lists.trolltech.com/qt-interest/2004-10/thread00024-0.html
+ */
+                        char tbuf[BUFFSIZE];
+                        char *tptr1 = ibuf;
+                        char *tptr2 = tbuf;
+                        int no = n;
+                        int nr = 0;
+                        while (no)
+                        {
+                            if (*tptr1 != '\0')
+                            {
+                                *tptr2++ = *tptr1;
+                                nr++;
+                            }
+                            tptr1++;
+                            no--;
+                        }
+
+                        int r=writen(mfd,tbuf,nr);
                         if (fwbdebug) qDebug("Wrote %d bytes to mfd",r);
+#ifdef DEBUG_INSTALLER
+                        write(debug_file,tbuf,nr);
+#endif
                     }
                 }
                 if (FD_ISSET(mfd, &rfds))
@@ -522,6 +548,10 @@ int main( int argc, char ** argv )
                 }
             }
         }
+
+#ifdef DEBUG_INSTALLER
+        close(debug_file);
+#endif
         int status;
         waitpid(pid, &status, 0);
         if (WIFEXITED(status)) exit(WEXITSTATUS(status));
