@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSData.cpp,v 1.1 2004/03/10 08:41:33 vkurland Exp $
+  $Id: OSData.cpp,v 1.3 2004/10/25 04:23:14 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -28,19 +28,23 @@
 
 using namespace std;
 
-OSData::OSData(){}
 
 string  OSData::getPathForTool(const string &distro,tools t)
 {
     string r="/FWBuilderResources/Target/tools/"+distro+"/";
+
+    if (Resources::os_res[host_os]->getResourceStr(r+"path_ip").empty())
+        r="/FWBuilderResources/Target/tools/Unknown/";
+
     switch (t)
     {
-    case LSMOD:    r+="path_lsmod";    break;
-    case MODPROBE: r+="path_modprobe"; break;
-    case IPTABLES: r+="path_iptables"; break;
-    case IP:       r+="path_ip";       break;
-    case LOGGER:   r+="path_logger";   break;
+    case LSMOD:            r+="path_lsmod";            break;
+    case MODPROBE:         r+="path_modprobe";         break;
+    case IPTABLES:         r+="path_iptables";         break;
+    case IPTABLES_RESTORE: r+="path_iptables_restore"; break;
+    case IP:               r+="path_ip";               break;
+    case LOGGER:           r+="path_logger";           break;
     }
-    return Resources::os_res["linux24"]->getResourceStr(r);
+    return Resources::os_res[host_os]->getResourceStr(r);
 }
 
