@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: OSConfigurator_solaris.cpp,v 1.1 2004/05/11 06:06:29 vkurland Exp $
+  $Id: OSConfigurator_solaris.cpp,v 1.1.4.1 2006/03/19 06:08:18 vkurland Exp $
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -184,7 +184,7 @@ void  OSConfigurator_solaris::printPathForAllTools(const string &os)
     output << "  addr=$1"    << endl;
     output << "  nm=$2"      << endl;
     output << "  dev=$3"     << endl;
-    output << "  ( ifconfig $dev | egrep -q \"inet +${addr} \" ) || " << endl;
+    output << "  ( ifconfig $dev | egrep -s \"inet +${addr} \" ) || " << endl;
     output << "    { "       << endl;
     output << "      echo \"$dev: $addr\"" << endl;
     output << "      ifconfig $dev $addr alias" << endl; 
